==> nextcloud-app-calendar-1%3A5.5.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/af.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s het die kalender »%s« gepubliseer",
    "Hello," : "Dag,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ons wil u graag inlig dat %s die kalender »%s« gepubliseer het.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Geluk!",
    "Calendar" : "Kalender",
    "Confirm" : "Bevestig",
    "Location:" : "Ligging:",
    "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
    "Today" : "Vandag",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "List" : "Lys",
    "Preview" : "Voorskou",
    "Copy link" : "Kopieer skakel",
    "Edit" : "Wysig",
    "Delete" : "Skrap",
    "New calendar" : "Nuwe kalender",
    "Export" : "Voer uit",
    "Name" : "Naam",
    "Deleted" : "Geskrap",
    "Restore" : "Herstel",
    "Delete permanently" : "Skrap permanent",
    "Share link" : "Deel skakel",
    "can edit" : "kan wysig",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "Save" : "Stoor",
    "View" : "Bekyk",
    "Filename" : "Lêernaam",
    "Cancel" : "Kanselleer",
    "Automatic" : "Outomaties",
    "Automatic ({timezone})" : "Outomaties ({timezone})",
    "Timezone" : "Tydsone",
    "List view" : "Lysaansig",
    "Actions" : "Aksies",
    "Show week numbers" : "Toon weeknommers",
    "Keyboard shortcuts" : "Sneltoetse",
    "Update" : "Werk by",
    "Location" : "Ligging",
    "Description" : "Beskrywing",
    "Duration" : "Duur",
    "to" : "aan",
    "Add" : "Voeg by",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "Sunday" : "Sondag",
    "Your email address" : "U e-posadres",
    "Notification" : "Kennisgewing",
    "Email" : "E-pos",
    "seconds" : "sekondes",
    "minutes" : "minute",
    "hours" : "uur",
    "days" : "dae",
    "weeks" : "weke",
    "Delete file" : "Skrap lêer",
    "Available" : "Beskikbaar",
    "Not available" : "Onbeskikbaar",
    "Unknown" : "Onbekend",
    "Accept" : "Aanvaar",
    "Tentative" : "Tentatief",
    "Attendees" : "Bywoners",
    "From" : "Van",
    "To" : "Aan",
    "Repeat" : "Herhaal",
    "never" : "nooit",
    "after" : "na",
    "Resources" : "Hulpbronne",
    "available" : "beskikbaar",
    "Global" : "Globaal",
    "Subscribe" : "Teken in",
    "Personal" : "Persoonlik",
    "All day" : "Heeldag",
    "Close" : "Sluit",
    "Submit" : "Dien in",
    "Anniversary" : "Herdenking",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Daily" : "Daagliks",
    "Weekly" : "Weekliks",
    "second" : "sekonde",
    "Other" : "Ander",
    "Status" : "Status",
    "Confirmed" : "Bevestig",
    "Categories" : "Kategorieë",
    "Hidden" : "Versteek"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A6.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/af.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s het die kalender »%s« gepubliseer",
    "Hello," : "Dag,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Ons wil u graag inlig dat %s die kalender »%s« gepubliseer het.",
    "Open »%s«" : "Open »%s«",
    "Cheers!" : "Geluk!",
    "Calendar" : "Kalender",
    "Confirm" : "Bevestig",
    "Location:" : "Ligging:",
    "A Calendar app for Nextcloud" : "'n Kalendertoep vir Nextcloud",
    "Today" : "Vandag",
    "Day" : "Dag",
    "Week" : "Week",
    "Month" : "Maand",
    "List" : "Lys",
    "Preview" : "Voorskou",
    "Copy link" : "Kopieer skakel",
    "Edit" : "Wysig",
    "Delete" : "Skrap",
    "New calendar" : "Nuwe kalender",
    "Export" : "Voer uit",
    "Name" : "Naam",
    "Deleted" : "Geskrap",
    "Restore" : "Herstel",
    "Delete permanently" : "Skrap permanent",
    "Share link" : "Deel skakel",
    "Share with users or groups" : "Deel met gebruikers of groepe",
    "No users or groups" : "Geen gebruikers of groepe",
    "Save" : "Stoor",
    "View" : "Bekyk",
    "Filename" : "Lêernaam",
    "Cancel" : "Kanselleer",
    "Automatic" : "Outomaties",
    "Automatic ({timezone})" : "Outomaties ({timezone})",
    "Timezone" : "Tydsone",
    "List view" : "Lysaansig",
    "Actions" : "Aksies",
    "Files" : "Lêer ",
    "Update" : "Werk by",
    "Location" : "Ligging",
    "Description" : "Beskrywing",
    "Duration" : "Duur",
    "to" : "aan",
    "Add" : "Voeg by",
    "Monday" : "Maandag",
    "Tuesday" : "Dinsdag",
    "Wednesday" : "Woensdag",
    "Thursday" : "Donderdag",
    "Friday" : "Vrydag",
    "Saturday" : "Saterdag",
    "Sunday" : "Sondag",
    "Your email address" : "U e-posadres",
    "Notification" : "Kennisgewing",
    "Email" : "E-pos",
    "seconds" : "sekondes",
    "minutes" : "minute",
    "hours" : "uur",
    "days" : "dae",
    "weeks" : "weke",
    "Delete file" : "Skrap lêer",
    "Available" : "Beskikbaar",
    "Not available" : "Onbeskikbaar",
    "Unknown" : "Onbekend",
    "Accept" : "Aanvaar",
    "Tentative" : "Tentatief",
    "Attendees" : "Bywoners",
    "From" : "Van",
    "To" : "Aan",
    "Repeat" : "Herhaal",
    "never" : "nooit",
    "after" : "na",
    "Resources" : "Hulpbronne",
    "available" : "beskikbaar",
    "None" : "Geen",
    "Global" : "Globaal",
    "Subscribe" : "Teken in",
    "Personal" : "Persoonlik",
    "All day" : "Heeldag",
    "Close" : "Sluit",
    "Submit" : "Dien in",
    "Anniversary" : "Herdenking",
    "Week {number} of {year}" : "Week {number} van {year}",
    "Daily" : "Daagliks",
    "Weekly" : "Weekliks",
    "second" : "sekonde",
    "Other" : "Ander",
    "Status" : "Status",
    "Confirmed" : "Bevestig",
    "Categories" : "Kategorieë",
    "Hidden" : "Versteek",
    "can edit" : "kan wysig",
    "Show week numbers" : "Toon weeknommers",
    "Keyboard shortcuts" : "Sneltoetse"
},
"nplurals=2; plural=(n != 1);");
